#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>


/*
 * See where program (bin) resides in the $PATH specified by (envr).
 *  returns a copy of the first element in envr that contains it, or NULL
 *  if it doesn't exist or there were other problems. PHYSFS_SetError() is
 *  called if we have a problem.
 *
 * (envr) will be scribbled over, and you are expected to allocator.Free() the
 *  return value when you're done with it.
 */
static char *findBinaryInPath(const char *bin, char *envr)
{
    size_t alloc_size = 0;
    char *exe = NULL;
    char *start = envr;
    char *ptr;

    if (bin == NULL) return NULL;
    if (envr == NULL) return NULL;

    do
    {
        size_t size;
        ptr = strchr(start, ':');  /* find next $PATH separator. */
        if (ptr)
            *ptr = '\0';

        size = strlen(start) + strlen(bin) + 2;
        if (size > alloc_size)
        {
            char *x = (char *) realloc(exe, size);
            if (x == NULL)
            {
                if (exe != NULL)
                    free(exe);
                return NULL;
            } /* if */

            alloc_size = size;
            exe = x;
        } /* if */

        /* build full binary path... */
        strcpy(exe, start);
        if ((exe[0] == '\0') || (exe[strlen(exe) - 1] != '/'))
            strcat(exe, "/");
        strcat(exe, bin);

        if (access(exe, X_OK) == 0)  /* Exists as executable? We're done. */
        {
            strcpy(exe, start);  /* i'm lazy. piss off. */
            return(exe);
        } /* if */

        start = ptr + 1;  /* start points to beginning of next element. */
    } while (ptr != NULL);

    if (exe != NULL)
        free(exe);

    return(NULL);  /* doesn't exist in path. */
} /* findBinaryInPath */

static char *copyEnvironmentVariable(const char *varname)
{
    const char *envr = getenv(varname);
    char *retval = NULL;

    if (envr != NULL)
    {
        retval = (char *) malloc(strlen(envr) + 1);
        if (retval != NULL)
            strcpy(retval, envr);
    } /* if */

    return(retval);
} /* copyEnvironmentVariable */


char *calcBaseDir(const char *argv0)
{
    /* If there isn't a path on argv0, then look through the $PATH for it. */
    char *retval;
    char *envr;

    if (strchr(argv0, '/') != NULL)   /* default behaviour can handle this. */
    {
        retval = malloc(strlen(argv0));
        strcpy(retval, argv0);
        *(strrchr(retval, '/')) = '\0';
        return retval;
    }

    envr = copyEnvironmentVariable("PATH");
    if (!envr) return NULL;
    retval = findBinaryInPath(argv0, envr);
    free(envr);
    return(retval);
} /* calcBaseDir */


static void chdirForAppBundle(char *argv0)
{
    char *base = calcBaseDir(argv0);
    if (base == NULL) return;  // oh well.
    char *ptr = strstr(base, "/Contents/MacOS");
    if (ptr) *ptr = '\0';
    chdir(base);
    free(base);
}

int main(int argc, char **argv)
{
    chdirForAppBundle(argv[0]);
    argv[0] = "./RocketBowl-bin";
    execv(argv[0], argv);
    return(1);  // exec failed
}

