//==============================================================================
// File    : author.js
//------------------------------------------------------------------------------
//
// This file ease HTML customization
//
// You may customize this file according to your needs.
//
// Steps:
// 1) Customize product data
// 2) Customize publisher information. You can leave without value any variable
//    you do not need
// 3) (Optional) Customize texts to display to end-users in the following
//    functions:
//    - showTrialStatus()
//    - showFooterLinks()
//    - showPublisherSupportLink()
//    - showPublisherSiteLink()
//
// Please read the Authoring Guidelines documentation for further information.
//==============================================================================
// Product data
//==============================================================================


// Constants
var AM_CALLER_PAGE = "ActiveMARK_callerpage";


// Name
var g_product_name = "Product Name";
var g_title_margin = 6; // separation from the left margin to the image tittle 
                        // or name (measured in em's)
var product_image  = "images/product/box.jpg";

var g_tg_affiliates=new Array(
 "trygames.*",
 "zz_.*",
 "z_.*",
 "t_np.*",
 "ls.*",
 "news.*",
 "popunder.*",
 "se_.*",
 "infogrames.*"
);

//==============================================================================
// Publisher information
//==============================================================================

// Name
var g_publisher_name = "Publisher";
// Website url. Eg: g_publisher_url = "http://www.publisher.com";
var g_publisher_url  = ""; 
// Support center name. 
// Eg: g_support_name = "Publisher's Customer Support Center"
var g_support_name   = "";  
// Support center URL. Eg: g_support_url = "http://www.publisher.com/support"
var g_support_url    = ""; 
// Image to display in showPublisherLogo function. The value is the relative 
// path where the image is. 
// Eg: g_publisher_logo = "images/product/publisher.gif";
var g_publisher_logo = "";



//==============================================================================
// showTrialStatus
//
// Shows text explaining the current trial status
//==============================================================================
function showTrialStatus() {
  // Only the following combination of configuration parameters is allowed:
  //  ((TIME && DAYS && USES) || (TIME && DAYS) || (TIME && USES) || 
  //   (DAYS && USES) || TIME || DAYS || USES)
  // Where:
  // TIME = (PUT && MUT) || PUT || MUT
  // DAYS = EDT || EDY
  // USES = EUS
  // PUT = per_usage_time
  // MUT = maximum_usage_time
  // EUS = expiration_uses
  // EDT = expiration_date
  // EDY = expiration_days

  // Parse the configuration parameters for time-limited trials
  var put, mut, eus, edy, exttrial;

  put = param.perusagetime? getRemaining(param.perusagetime) : 0;
  mut = param.maximumusagetime? getRemaining(param.maximumusagetime) : 0;
  eus = param.expirationuses? getRemaining(param.expirationuses) : 0;
  if (param.expirationdate) {
    var date0 = string2Date (param.currenttime);
    var date1 = string2Date (param.expirationdate);

    edy = Math.ceil (diffdates (date1, date0).getTime() / 86400000);
  }
  else if (param.expirationdays) {
    if (param.firstusage) {
      var date0 = string2Date (param.firstusage);
      var date1 = string2Date (param.currenttime);

      edy = Math.floor (diffdates (date1, date0).getTime() / 86400000);
      edy = param.expirationdays - edy;
    }
    else {
      edy = param.expirationdays;
    }
  }
  else {
    edy = 0;
  }
  exttrial = (param.extendedtrial == 1)

  // Get the trial status string
  var trialstatus   = getTrialStatusString (put, mut, eus, edy, exttrial);
  var customTstring = getCustomTrialString (); 

  if (customTstring) {
    if (trialstatus) {
      trialstatus += " " + customTstring;
    } else {
      trialstatus = customTstring;
    }
  }
  
  if (trialstatus) {
    document.write (trialstatus);
    return true;
  }

  return false;
}

//==============================================================================
// Function showTrialStatusShortFormat
// 
// Shows a short message explaining the current trial status
//==============================================================================
function showTrialStatusShortFormat() {
  // Get remaining time
  var mut, put, remtime;

  mut = (param.maximumusagetime)? getRemaining(param.maximumusagetime) : 0;
  put = (param.perusagetime)? getRemaining(param.perusagetime) : 0;

  if (put && !mut) remtime = put;
  else if (!put && mut) remtime = mut;
  else if (put && mut) remtime = (mut < put)? mut : put;

  // Get remaining uses
  var remuses = (param.expirationuses)? getRemaining(param.expirationuses) : 0;

  // Get remaining days
  var remdays = 0;

  if (param.expirationdays) {
    if (param.firstusage) {
      var date0 = string2Date (param.firstusage);
      var date1 = string2Date (param.currenttime);

      remdays = Math.floor (diffdates (date1, date0).getTime() / 86400000);
      remdays = param.expirationdays - remdays;
    }
    else {
      remdays = param.expirationdays;
    }
  }
  else if (param.expirationdate) {
    var date0 = string2Date (param.currenttime);
    var date1 = string2Date (param.expirationdate);
    var remainingdate = diffdates (date1, date0);

    remdays = Math.ceil (remainingdate.getTime() / 86400000);
  }

  // Get the trial status string
  var trialstatus = getShortTrialStatusString (remtime, remuses, remdays);

  var customTstring = getCustomTrialString (); 

  if (customTstring) {
    if (trialstatus) {
      trialstatus += " " + customTstring;
    } else {
      trialstatus = customTstring;
    }
  }

  if (trialstatus) {
    document.write (trialstatus);
    return true;
  }

  return false;
}

//==============================================================================
// Function showFooterLinks()
//
// Shows the footer links
//==============================================================================
function showFooterLinks() {
  var code;
  var common;

  common  = "if (!getCookie(AM_CALLER_PAGE)) setCookie ";
  common += "(AM_CALLER_PAGE, window.location);";

  code  = '<a href="javascript:' + common +'window.location=AM_Compose_URL';
  code += '(\'howthisworks_' + getIsoCode(g_currentLang) + '.html?lang=';
  code += 'getIsoCode(g_currentLang)\');" style="color: white;">';
  document.write (code);

  printString (_HOW_);

  code  = '</a> | <a href="javascript:' + common + 'window.location=';
  code += 'AM_Compose_URL (\'privacy_' + getIsoCode(g_currentLang);
  code += '.html?lang=' +  getIsoCode(g_currentLang);
  code += '\');" style="color: white;">';
  document.write (code);

  printString (_PRIVACY_);

  code  = '</a> | <a href="javascript:' + common + 'window.location=';
  code += 'AM_Compose_URL' + '(\'helpsupport.html?lang=';
  code += getIsoCode(g_currentLang) + '\');" style="color: white;">';
  document.write (code);

  printString (_HELP_);

  document.write('</a>');
}

//==============================================================================
// Function showPublisherSupportLink()
//
// Shows Publisher's Support Link
//==============================================================================
function showPublisherSupportLink() {
  if ((g_support_url != "") && (g_support_name != "")) {
    var code;

    code  = '<tr valign="top"> <td><img src="images/generics/li.gif" ';
    code += 'width="4" height="10"></td><td><script language="JavaScript" ';
    code += 'type="text/javascript">printStringPublisherSupportLink';
    code += '(g_currentLang, g_support_url, g_support_name)</script>';
    code += '<br><br></td></tr>';

    document.write (code);
  }
}

//==============================================================================
// Function showPublisherSiteLink()
//
// Shows Publisher's Support Link
//==============================================================================
function showPublisherSiteLink() {
  if ((g_publisher_url != "") && (g_publisher_name != ""))  {
    var code;

    code  = '<tr valign="top"><td><img src="images/generics/li.gif" width="4" ';
    code += 'height="10"></td><td><script language="JavaScript" ';
    code += 'type="text/javascript">printStringPublisherSiteLink';
    code += '(g_currentLang, g_publisher_url, g_publisher_name)</script>';
    code += '<br> <br> </td></tr>';

    document.write(code);
  }
}

//==============================================================================
// Function getRemaining
// 
// Returns the remaining time or the remaining uses (strcriteria 
// format: current/total)
//==============================================================================
function getRemaining (strcriteria) {
   var aux = strcriteria.split("/");
   return aux[1] - aux[0];
}

//==============================================================================
// Function string2Date
//==============================================================================
function string2Date (strdate) {
  var dtokens = strdate.match (/(\d+)\/(\d+)\/(\d+)@(\d+):(\d+):(\d+)/);

  return new Date(
    dtokens[1], dtokens[2], dtokens[3], dtokens[4], dtokens[5], dtokens[6]
  );
}

//==============================================================================
// Function diffdates
//==============================================================================
function diffdates (date0, date1) {
  return new Date (date0.getTime() - date1.getTime());
}

//==============================================================================
// DO NOT TOUCH ANYTHING BELOW THIS POINT
//==============================================================================



//==============================================================================
// Determine browser version and support functions
//==============================================================================

// *** BROWSER VERSION ***
// convert all characters to lowercase to ease testing
var g_isIE  = ((navigator.userAgent.toLowerCase().indexOf("msie") != -1) &&
               (navigator.userAgent.toLowerCase().indexOf("opera") == -1))
var g_isIE3 = (g_isIE && (parseInt (navigator.appVersion) < 4));
var g_isIE4 = (g_isIE && (parseInt (navigator.appVersion) == 4));
var g_isIE5 = isMSIE5();

// get query string
var param = getParameters();


//==============================================================================
// getParameters
//
// Gets parameters form url and load param array with them
//==============================================================================
function getParameters() {
  var myparam = new Object();
  var strquery = top.parent.location.search.substring(1);
  // split the pairs (Break at &)
  var pairs = new Array();
  var ini = 0;
  var y = 0;

  for (var i = 0; i < strquery.length; i++) {
    if (strquery.charAt(i) == "&") {
      pairs[y] = strquery.substring(ini,i);
      y++;
      ini = i + 1;
    }    
  }

  pairs[y] = strquery.substring(ini,strquery.length);
  for (var i = 0; i < pairs.length; i++) {
    //get the position for the query environment string
    var pos = pairs[i].indexOf('=');
    if (pos == -1) continue; //if not found, skip

    //get the name
    var name = pairs[i].substring(0,pos);

    //get the value
    var value = pairs[i].substring(pos+1);
    myparam[name] = unescape(value);
  }

  return myparam;
}

//==============================================================================
// isMSIE5
// ----------------------------------------------------------------------------
// Returns true if the current browser is MS IE 5, otherwise false
//==============================================================================
function isMSIE5() {  
  var ua = window.navigator.userAgent;
  var msie = ua.indexOf("MSIE ");
  if (msie > 0) {
    if (parseInt(ua.substring(msie+5,ua.indexOf(".",msie))) >= 5)
      return true;
    else return false;
  }
  else return false;
}

//==============================================================================
// trim
// ----------------------------------------------------------------------------
// Removes leading and trailing spaces from the passed string. Also removes
// consecutive spaces and replaces it with one space.
// Does nothing unless inputString is a string
//==============================================================================
function trim(inputString) {
  if (typeof inputString != "string") return inputString;

  var retValue = inputString;
  var ch = retValue.substring(0, 1);

  while (ch == " ") { // Check for spaces at the beginning of the string
    retValue = retValue.substring(1, retValue.length);
    ch = retValue.substring(0, 1);
  }

  ch = retValue.substring(retValue.length-1, retValue.length);
  while (ch == " ") { // Check for spaces at the end of the string
    retValue = retValue.substring(0, retValue.length-1);
    ch = retValue.substring(retValue.length-1, retValue.length);
  }

  return retValue; // Return the trimmed string back to the user
}

//==============================================================================
// function showPrice()
//
// Shows the currency and price
//==============================================================================
function showPrice() {
  if (param.price && param.currency) {
    document.write('<span class="currency"><strong>');

    param.currency = trim (param.currency);

    if (g_isIE5 || g_isIE4) {
      switch (param.currency.toUpperCase()) {
        case "USD": document.write("$"); break;
        case "GBP": document.write("&pound;"); break;
        case "JPY": document.write("&yen;"); break;
        case "CAD": document.write("CA $"); break;
        case "AUD": document.write("AU $"); break;
        case "NZD": document.write("NZ $"); break;
        case "EUR": 
          (g_isIE5)? document.write("&euro;") : document.write("EUR ");
          break;
        default: document.write (param.currency + " ");
      }
    }
    else {
      document.write(param.currency + " ");
    }
    
    document.write('</span></strong>');
  }

  if (param.price) {
    document.write('<span class="price"><strong>');
    document.write (Math.floor(param.price / 100));

    if (param.currency) {
      if (param.currency.toUpperCase() != "JPY") { 
        document.write("." + param.price % 100);
        if (param.price % 100 == 0) document.write(0);
      }
    } 
    else {
      document.write ("." + param.price % 100);
      if (param.price % 100 == 0) document.write(0);
    }

    document.write('</strong></span>');
  }
}

//==============================================================================
// Function showAffiliateLogo()
//
// Show trygames logo if affiliate is trygames.
//==============================================================================

function showAffiliateLogo() {
   var aff = param.affiliate;
	var show_tg_logo = 0;
	if (aff) {
     for (i = 0; i < g_tg_affiliates.length; i++) 
	  {
       var re = new RegExp("^(" + g_tg_affiliates[i] + ")$");
       if (aff.search(re) != -1) 
	    {
         show_tg_logo = 1;
       }
     }
	}
	
   if (show_tg_logo) {
    document.write(
      '<td align="right" valign="top"><a href="http://www.trygames.com" ' + 
      'target="_blank"><img src="images/product/trygames.gif" ' + 
      'alt="Trygames" width="99" height="25" border="0"></a></td>'
    );
   }
}

//==============================================================================
// Function showPublisherLogo()
//
// Shows publisher logo any
//==============================================================================
function showPublisherLogo() {
  if (g_publisher_logo) {
    if (g_publisher_url) {
      document.write(
        '<td width="99" height="25"><a href="http://' + g_publisher_url + 
        '" target="_blank" ><img src="' + g_publisher_logo + '" alt="' + 
        g_publisher_name + '" border="0"></a></td>'
      );
    }
    else {
      document.write(
        '<td width="99" height="25"><img src="' + g_publisher_logo + '" alt="' +
        g_publisher_name+'" ></td>'
       );
    }
  }
}

//==============================================================================
// Function showProductName()
//
// Shows product name.
//==============================================================================
function showProductName() {
  if (g_product_name) {
    document.write(
      '<div style="margin-left:' + g_title_margin + 'em;">' +  g_product_name + 
      '</div>'
    );
  }
  else {
    document.write(
      '<div style="margin-left:'+ g_title_margin +
      'em;"><img src="images/product/title.jpg" border="0"></div>'
    );
 }
}

//==============================================================================
// Function showProductfeatures()
//
// Shows Product's feature list
//==============================================================================
function showProductfeatures() {
  for (var i = 0; i < g_features[g_currentLang].length; i++) {
    if (g_features[g_currentLang][i] != "") {
      document.write(
        '<tr valign="top" height="20"><td width="20"><img ' + 
        'src="images/generics/li.gif" width="4" height="10" border="0" ' + 
        'align="absmiddle"></td><td>' + g_features[g_currentLang][i] + 
        '<br> </td></tr>'
      );
    }
  }  
}

//==============================================================================
// Function showRelicense() 
//
// Shows Relicense link
//==============================================================================
function showRelicense (activationpage) {
  var width_lang;
  var style;

  if(
    (g_currentLang == _ENGLISH_LANG_) || 
    (g_currentLang == _FRENCH_LANG_) ||
    (g_currentLang == _DUTCH_LANG_)
  )
  {
    width_lang = 160;
  }
  else {
    width_lang = 230;
  }

  style  = 'style="font-family: Verdana, Arial, Helvetica, sans-serif; ';
  style += 'border: 0; background-color: transparent; text-decoration: ';
  style += 'underline; font-size: 11px; font-weight: bold; color : #000099; ';
  style += 'cursor: hand; width: ' + width_lang + 'px; height:15px;"';

  if (activationpage) {
    document.write ('<a href="' + activationpage + '" ' + style + '>');
    printString (_RELICENSE_);
    document.write ('</a>');
  }
  else {
    document.write ('<input type="submit" value="');
    printString (_RELICENSE_);
    document.write ('"' + style + '>');
  }
}
//==============================================================================
// Function setProductImageHint()
//
// Sets product image alt text with the product name
//==============================================================================
function setProductImageHint() {
  document.box_image.alt = g_product_name;
  document.box_image.src = product_image;
}


//==============================================================================
// Function setTitle()
//
// Sets window title to product name
//==============================================================================
function setTitle() {
  document.title = g_product_name;
}


//==============================================================================
// Function goBack()
//
// Loads the original caller page.
//==============================================================================
function goBack() {
  var page = getCookie (AM_CALLER_PAGE);

  if (!page) {
    history.go (-1);
    return;
  }

  // Delete the cookie  
  var expire = new Date(); 
  expire.setFullYear(expire.getFullYear() - 1);
  setCookie (AM_CALLER_PAGE, "", expire);

  // Navigate to the caller page
  page = page.replace (/lang=[a-z]{2}/i, "lang=" + getIsoCode (g_currentLang));
  window.location = page;
}


//==============================================================================
// Function setCookie
//
// Sets a cookie for the current url
//==============================================================================
function setCookie (name, value, expire) {
  var cookie;
  var url = window.location.href;
  var tokens  = url.split(/\//);
  
  cookie  = escape(name) + "=" + escape(value);
  cookie += (expire)? "; expires=" + expire.toGMTString() : "";
  cookie += "; domain=" + tokens[1];
  cookie += "; path=/";

  document.cookie = cookie;
}


//==============================================================================
// Function getCookie
//
// Retrieves the value of a specified cookie
//==============================================================================
function getCookie (name) {
  var ctokens = document.cookie.match (unescape(name) + "=(.*)");
  return (ctokens == null)? null : unescape(ctokens[1]);
}
